dm: treewide: Rename 'platdata' variables to just 'plat'

We use 'priv' for private data but often use 'platdata' for platform data.
We can't really use 'pdata' since that is ambiguous (it could mean private
or platform data).

Rename some of the latter variables to end with 'plat' for consistency.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/arch/x86/cpu/apollolake/hostbridge.c b/arch/x86/cpu/apollolake/hostbridge.c
index 4b627e3..cb5a816 100644
--- a/arch/x86/cpu/apollolake/hostbridge.c
+++ b/arch/x86/cpu/apollolake/hostbridge.c
@@ -403,7 +403,7 @@
 	.ofdata_to_platdata = apl_hostbridge_ofdata_to_platdata,
 	.probe		= apl_hostbridge_probe,
 	.remove		= apl_hostbridge_remove,
-	.platdata_auto	= sizeof(struct apl_hostbridge_platdata),
+	.plat_auto	= sizeof(struct apl_hostbridge_platdata),
 	ACPI_OPS_PTR(&apl_hostbridge_acpi_ops)
 	.flags		= DM_FLAG_OS_PREPARE,
 };
diff --git a/arch/x86/cpu/apollolake/pmc.c b/arch/x86/cpu/apollolake/pmc.c
index 82e2187..10a4b02 100644
--- a/arch/x86/cpu/apollolake/pmc.c
+++ b/arch/x86/cpu/apollolake/pmc.c
@@ -224,5 +224,5 @@
 	.ofdata_to_platdata = apl_pmc_ofdata_to_uc_platdata,
 	.probe		= apl_pmc_probe,
 	.ops		= &apl_pmc_ops,
-	.platdata_auto	= sizeof(struct apl_pmc_platdata),
+	.plat_auto	= sizeof(struct apl_pmc_platdata),
 };
diff --git a/arch/x86/cpu/apollolake/uart.c b/arch/x86/cpu/apollolake/uart.c
index 6695234..44eba0c 100644
--- a/arch/x86/cpu/apollolake/uart.c
+++ b/arch/x86/cpu/apollolake/uart.c
@@ -92,7 +92,7 @@
 	struct ns16550_platdata *plat;
 
 	/*
-	 * Convert our platdata to the ns16550's platdata, so we can just use
+	 * Convert our plat to the ns16550's plat, so we can just use
 	 * that driver
 	 */
 	plat = malloc(sizeof(*plat));
@@ -105,7 +105,7 @@
 	plat->clock = dtplat->clock_frequency;
 	plat->fcr = UART_FCR_DEFVAL;
 	plat->bdf = pci_ofplat_get_devfn(dtplat->reg[0]);
-	dev->platdata = plat;
+	dev->plat = plat;
 #else
 	int ret;
 
@@ -126,7 +126,7 @@
 	.name	= "intel_apl_ns16550",
 	.id	= UCLASS_SERIAL,
 	.of_match = apl_ns16550_serial_ids,
-	.platdata_auto	= sizeof(struct ns16550_platdata),
+	.plat_auto	= sizeof(struct ns16550_platdata),
 	.priv_auto	= sizeof(struct NS16550),
 	.ops	= &ns16550_serial_ops,
 	.ofdata_to_platdata = apl_ns16550_ofdata_to_platdata,
diff --git a/arch/x86/cpu/apollolake/spl.c b/arch/x86/cpu/apollolake/spl.c
index 324dd6c..4110619 100644
--- a/arch/x86/cpu/apollolake/spl.c
+++ b/arch/x86/cpu/apollolake/spl.c
@@ -85,7 +85,7 @@
 
 /*
  * Manually set the parent of the SPI flash to SPI, since dtoc doesn't. We also
  * need to allocate the parent_platdata since by the time this function is
  * called device_bind() has already gone past that step.
  */
 static int apl_flash_bind(struct udevice *dev)
@@ -104,7 +104,7 @@
 		plat = calloc(sizeof(*plat), 1);
 		if (!plat)
 			return -ENOMEM;
-		dev->parent_platdata = plat;
+		dev->parent_plat = plat;
 	}
 
 	return 0;
@@ -85,7 +85,7 @@
 /*
  * Manually set the parent of the SPI flash to SPI, since dtoc doesn't. We also
- * need to allocate the parent_platdata since by the time this function is
+ * need to allocate the parent_plat since by the time this function is
  * called device_bind() has already gone past that step.
  */